<%

' =====================================================
' HELPERS
' =====================================================

' -----------------------------------------------------
' function SafeText
' Tidy up a string and make sure it's suitable for HTML
' -----------------------------------------------------
function SafeText(str)

str=trim(str)

if str = "" then
	SafeText="N/A"
else
	SafeText=Server.HTMLEncode(str)
end if

end function


' -----------------------------------------------------
' function GetBestSender
' Get the best guess we have as to who sent the message - try 
' these in order:
'	Reply-To
'	From
'	Return-Path
' -----------------------------------------------------
function GetBestSender(msg)

if msg.ReplyTo.Count>0 then
	GetBestSender=msg.ReplyTo(1)
elseif msg.From.Count>0 then
	GetBestSender=msg.From(1)
elseif msg.Header("Return-Path")<>"" then
	GetBestSender=msg.Header("Return-Path")
else
	GetBestSender="N/A"
end if

GetBestSender=Server.HTMLEncode(GetBestSender)

end function



' -----------------------------------------------------
' function GetBestRecipient
' Get the best guess of the recipient - try these in 
' order:
'	To
'	X-Envelope-To
'	Envelope-To
' -----------------------------------------------------
function GetBestRecipient(msg)

if msg.To.Count>0 then
	GetBestRecipient=msg.To(1)
elseif msg.Header("X-Envelope-To")<>"" then
	GetBestRecipient=msg.Header("X-Envelope-To")
elseif msg.Header("Envelope-To")<>"" then
	GetBestRecipient=msg.Header("Envelope-To")
else
	GetBestRecipient="N/A"
end if

GetBestRecipient=Server.HTMLEncode(GetBestRecipient)

end function

' -----------------------------------------------------
' function FindPOP3MessageByUIDL
' Find a message on the POP3 server given the message
' UIDL. The UIDL is a server assigned identifier which
' is persistent across sessions. The POP3 protocol does
' not, however, define any commands to look up messages
' by UIDL so we need to iterate over all the messages
' looking for the UIDL
' -----------------------------------------------------
function FindPOP3MessageByUIDL(uidl)
Set FindPOP3MessageByUIDL=nothing

for each msg in g_pop3.messages
	g_pop3.POP3UIDL msg.Ordinal
	if msg.UIDL=g_UIDL then
		Set FindPOP3MessageByUIDL=msg
	end if
next

end function


' -----------------------------------------------------
' function GetInfo
' Get parameters from either the session or a 'calling'
' form. Set the session info if it came from a form.
' -----------------------------------------------------
function GetInfo(str)

if Session(str)="" then
	Session(str)=Request.Form(str)
end if

GetInfo=Session(str)

end function

' -----------------------------------------------------
' function UIDLToFileSystem
' Take a UIDL and replace any non-file system characters 
' so that we can use it as a directory name
'
' A better way to do this might be have a dictionary 
' object to map UIDLs to filenames. As it is the 
' sample assumes that the translated UIDL will be as unique
' as the original UIDL. 
' -----------------------------------------------------
function UIDLToFileSystem(str)

'Locals
dim i
dim ch

for i =1 to len(str)
	ch=mid(str,i,1)

	if (ch >= "0" and ch <= "9") or (ch >= "A" and ch <= "Z") or (ch >= "a" and ch <= "z") or (instr("_-",ch)<>0) then
		UIDLToFileSystem=UIDLToFileSystem & ch
	else
		UIDLToFileSystem=UIDLToFileSystem & "_"
	end if
	
next

end function

' -----------------------------------------------------
' function GetAndCreateMessageCache
' Create a cache entry for the message. This consists
' of creating a directory for the attachments and
' saving the message object as a file.
' -----------------------------------------------------

function CreateMessageCache(msg)

'Locals
dim sCacheRoot

sCacheRoot=Server.MapPath("cache")&"\"&UIDLToFileSystem(msg.UIDL)

' Save message object
msg.SaveToFile(sCacheRoot&".wms_msg")

' 
Set fso=CreateObject("Scripting.FileSystemObject")
if not fso.FolderExists(sCacheRoot&"-files") then
	fso.CreateFolder(sCacheRoot&"-files") 
end if


CreateMessageCache=sCacheRoot&"-files"

end function


' -----------------------------------------------------
' function GetMessageCache
' Just return the message attachment directory.
' -----------------------------------------------------
function GetMessageCache(msg)
GetMessageCache=Server.MapPath("cache")&"\"&UIDLToFileSystem(msg.UIDL)&"-files"
end function

' -----------------------------------------------------
' function FindCachedMessage
' Find a message in the cache given a UIDL
' -----------------------------------------------------
function FindCachedMessage(uidl)

'Locals
dim sCacheRoot

set FindCachedMessage=nothing

sCacheRoot=Server.MapPath("cache")&"\"&UIDLToFileSystem(UIDL)

Set fso=CreateObject("Scripting.FileSystemObject")
if fso.FileExists(sCacheRoot&".wms_msg") then
	Set FindCachedMessage=CreateObject("CSMail.Message")
	FindCachedMessage.LoadFromFile(sCacheRoot&".wms_msg")
end if

end function

' -----------------------------------------------------
' sub RemoveMessageCache
' Delete the message cache
' -----------------------------------------------------
sub RemoveMessageCache(msg)
'Locals
dim sCacheRoot

sCacheRoot=Server.MapPath("cache")&"\"&UIDLToFileSystem(msg.UIDL)

Set fso=CreateObject("Scripting.FileSystemObject")
if fso.FileExists(sCacheRoot&".wms_msg") then
	fso.DeleteFile(sCacheRoot&".wms_msg")
end if

if fso.FolderExists(sCacheRoot&"-files") then
	fso.DeleteFolder(sCacheRoot&"-files") 
end if
	
end sub

%>

<%
' -----------------------------------------------------
' sub CleanUpCache
' Iterate over the attachment cache directories and 
' check that a matching message exists on the POP3 server. 
' If it doesn't then delete the directory.
' -----------------------------------------------------

sub CleanUpCache

' locals
dim fso				' File system Object
dim cache			' attachement cache 
dim delete
dim ndeleted
dim deletedmessages()

Set fso=CreateObject("Scripting.FileSystemObject")

if fso.FolderExists(Server.MapPath("cache")) then
	Set cache=fso.GetFolder(Server.MapPath("cache"))
	
	ndeleted=0
	for each folder in cache.SubFolders
		delete=true
		for each msg in g_pop3.Messages
			if UIDLToFileSystem(msg.UIDL)&"-files"=folder.name then
				delete=false
				exit for
			end if
		next

		if delete then
			redim preserve deletedmessages(ndeleted)
			deletedmessages(ndeleted)=left(folder.path,len(folder.path)-6)
			ndeleted=ndeleted+1
		end if

	next

	for each folder in deletedmessages
		fso.DeleteFolder(folder&"-files")
		fso.DeleteFile(folder&".wms_msg")
	next

end if

end sub

Dim g_LicInfo

sub SetRTLicenseInfo
	set g_LicInfo=CreateObject("CSMail.LicenseInfo")
	g_LicInfo.RuntimeLicenseFile=Server.MapPath("csmail.runtime.lic")
end sub

%>